@@ -5,7 +5,7 @@ use warnings;
 package Dancer2::Plugin::Queue;
 # ABSTRACT: Dancer2 plugin for message queue abstractions
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Dancer2::Plugin;
 use Class::Load qw/try_load_class/;
@@ -14,7 +14,7 @@ my %queues;
 my $conf;
 
 register queue => sub {
-    my ( $dsl, $name ) = plugin_args(@_);
+    my ( $dsl, $name ) = @_;
     $conf ||= plugin_setting();
 
     # if name not specified, DWIM or use 'default'
@@ -72,7 +72,7 @@ Dancer2::Plugin::Queue - Dancer2 plugin for message queue abstractions
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -183,12 +183,22 @@ L<https://github.com/PerlDancer/dancer2-plugin-queue>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Jason A. Crome
+=for stopwords Jason A. Crome Peter Mottram
+
+=over 4
+
+=item *
 
 Jason A. Crome <jason@crome-plated.com>
 
+=item *
+
+Peter Mottram <peter@sysnix.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by David Golden.
